/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1994
 * Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the Sun type 4 keyboard,
 * as interpreted by OpenWindows and X Consortium R4 and R5 servers.
 * Note that the X Consortium R6 keycodes are totally different.
 */

static const KeyCode sun4_codes [] = {

  /* Row 0 */
  8, 10,
  12, 13, 15, 17, 19, 21, 23, 24, 25, 14, 16, 18, 95, 73,
  28, 29, 30, 105,
  
  /* Row 1 */
  32, 33,
  36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 50,
  52, 53, 54, 78,
  
  /* Row 2 */
  56, 58,
  60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72,
  96,
  75, 76, 77, 132,

  /* Row 3 */
  79, 80,
  83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 49,
  98, 99, 100,
  
  /* Row 4 */
  102, 104,
  106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118,
  119, 120, 121, 97,
  
  /* Row 5 */
  125,
  126, 26, 127, 128, 129, 74, 20,
  101, 57
};
